@@ -14,6 +14,9 @@ from protox.encoding import (
 )
 from protox.exceptions import MessageDecodeError, FieldValidationError
 
+if False:
+    from protox.message import Message  # noqa
+
 __all__ = [
     'WireType',
     'Field',
@@ -38,6 +41,9 @@ __all__ = [
     'OneOf',
     'one_of',
     'MapField',
+
+    'field_type_by_name',
+    'field_types',
 ]
 
 
@@ -196,7 +202,13 @@ class UnpackedRepeatedStrategy(BaseRepeatedStrategy):
 
 
 class Repeated(Field):
-    def __init__(self, of_type: Type, *, number: int, packed: bool = False):
+    def __init__(
+        self,
+        of_type: Union[Type['Message'], Type[enum.IntEnum], Type[Field]],
+        *,
+        number: int,
+        packed: bool = False
+    ):
         from .message import Message
 
         if issubclass(of_type, Message):
@@ -211,7 +223,7 @@ class Repeated(Field):
             self._field = of_type(number=number)
 
         self._of_type = of_type
-        self._packed = packed
+        self._packed: bool = packed
         self._strategy: BaseRepeatedStrategy
 
         if packed:
@@ -421,7 +433,7 @@ class EnumField(Field):
             required=required,
         )
 
-        self._py_enum = py_enum
+        self._py_enum: Type[enum.IntEnum] = py_enum
 
     def encode_value(self, value: int) -> bytes:
         return encode_varint(value)
@@ -429,18 +441,19 @@ class EnumField(Field):
     def decode(self, stream: IO) -> Optional[int]:
         value = decode_varint(stream)
 
-        # Specifications: omit value that's not in the enum's variants
-        if value in list(self._py_enum):
+        # Specification: omit value that's not in the enum's variants
+        try:
             return self._py_enum(value)
-
-        return None
+        except ValueError:
+            return None
 
     def validate_value(self, value: int):
-        valid_values = [int(x) for x in self._py_enum]
-
-        if value not in valid_values:
+        try:
+            self._py_enum(value)
+        except ValueError:
             raise ValueError(
-                f'Expected an enum value of {repr(valid_values)}, got {value} instead'
+                f'Expected an enum value of {repr([x for x in self._py_enum])}, '
+                f'got {value} instead'
             )
 
     @staticmethod
@@ -684,7 +697,7 @@ class MessageField(Field):
         self,
         of_type,
         *,
-        number,
+        number: int,
         default=None,
         required=False,
     ):
@@ -726,7 +739,7 @@ class OneOf:
 
 one_of = OneOf
 
-field_by_name: Dict[str, Field] = {
+field_type_by_name: Dict[str, Field] = {
     'int32': Int32,
     'int64': Int64,
     'sint32': SInt32,
@@ -745,4 +758,4 @@ field_by_name: Dict[str, Field] = {
     'enum': EnumField,
 }
 
-fields: List[Field] = list(field_by_name.values())
+field_types: List[Field] = list(field_type_by_name.values())
