@@ -9,6 +9,9 @@ from protox.fields import Field, OneOf, Repeated, MessageField, MapField
 from protox.validated_dict import ValidatedDict
 from protox.validated_list import ValidatedList
 
+if False:
+    from protox.well_known_types.descriptor import DescriptorProto  # noqa
+
 __all__ = [
     'Message',
     'define_fields',
@@ -148,8 +151,11 @@ def define_fields(
 
 class MessageMeta(ABCMeta):
     def __new__(mcs, name, bases, namespace):
-        new_cls: Type[Message] = super().__new__(
-            mcs, name, bases, namespace
+        new_cls = super().__new__(
+            mcs,
+            name,
+            bases,
+            namespace,
         )
 
         if name != 'Message':
@@ -217,13 +223,13 @@ T = TypeVar('T')
 
 
 class Message(metaclass=MessageMeta):
-    # The following fields are set by metaclass
-    _field_by_name: Dict[str, Union[Field, Repeated]] = ...
-    _field_by_number: Dict[int, Union[Field, Repeated]] = ...
-    _one_of_by_field_name: dict = ...
+    # The following fields provided by metaclass
+    _field_by_name: Dict[str, Union[Field, Repeated]] = None
+    _field_by_number: Dict[int, Union[Field, Repeated]] = None
+    _one_of_by_field_name: dict = None
 
     # Provided by code generator
-    DESCRIPTOR = ...
+    DESCRIPTOR: 'DescriptorProto' = None
 
     _to_python: Optional[Callable] = None
     _from_python: Optional[Callable] = None
@@ -374,11 +380,14 @@ class Message(metaclass=MessageMeta):
             return None
 
     def is_empty(self) -> bool:
+        """
+        Returns False if at least one field was explicitly set
+        """
         return not bool(self._data)
 
     def is_initialized(self) -> bool:
         """
-        Checks if all required fields are set
+        Returns True if all required fields are set
         """
         for name, field in self._field_by_name.items():
             if field.required and name not in self._data:
@@ -442,10 +451,8 @@ class Message(metaclass=MessageMeta):
         if indent_level == 0:
             buffer.append(f"message {type(self).__name__}")
 
-        indent_level += 1
-
         for key, value in self._data.items():
-            self._format_value(key, value, buffer, indent_level)
+            self._format_value(key, value, buffer, indent_level + 1)
 
         return '\n'.join(buffer)
 
